@@ -3,7 +3,7 @@ import os
 import sys
 import pathlib
 
-print("0" + pathlib.Path(__file__).parent.absolute())
+print("0" + pathlib.Path(__file__))
 print("1" + os.path.dirname(os.path.realpath(__file__)))
 print("2" + sys.path[0])
 print("3" + os.path.dirname(os.path.realpath(sys.argv[0])))
